# Exercise A7 - Identifying website features

Exercise specify to try identify a set of properties from an EPiServer site by just navigating it.

1. Identify what **markup** is part of a shared layout.
2. Identify at least three **page types** and list their likely **properties** including data types.
3. Identify at least three **block types** and list their likely **properties** including data types.
4. Identify at least one **interactive feature**, like a form that the visitor can interact with.

---

## Absolut.com

These are speculations of course. It's only part of an exercise to conclude some stuff, even if they're not how Absolut.com is actually doing it.

### 1. Markup

There seems to be two separate sites in the same solution. `www.absolut.com` and `www.absolutdrinks.com` _(ignoring `www.absolutart.com` as its not directly linked from the navbar)_. They both have a very similar base layout for their content.

#### `www.absolut.com`
- White background theme.
- Absolut font pretty much everywhere
- Navbar, in it's transparent black fashion, containing:
  - logo
  - link to products
  - link to drinks
  - link to news
  - link to newsletter sign up
- > _~content goes here~_
- Footer, containing:
  - logo
  - language selection
  - link to press
  - link to contact
  - link to about the company
  - links to social platforms (youtube, twitter, facebook, instagram)
  - links to terms
  - links to policies (privacy & cookies)
  - copyrights

#### `www.absolutdrinks.com`
_Same as `www.absolut.com`, but with extra part in the header_
- Black background theme.
- _`...` same Navbar as above_
- Second navbar, containing
  - link to drinks start page
  - link to drinks category browsing
  - link to bartender learning guides
- > _~content goes here~_
- _`...` same Footer as above_

### 2. Page types

#### __Product__ `absolut.com/en/products/*`
_Example: Absolut Vodka, Absolut Citron, Absolut Lime_
- `text` Title/name
- `text` Summary
- `image` Splash image
- `content area` Big 'ol main content. Frequently containing:
  - Wide image background block
  - Text block
  - Drink recipes carousel block
  - Links to drinks block
- `nutritional block` Nutritions info

#### __Product *(deluxe)*__ `absolut.com/en/products/*`
_Example: Absolut Drop, Absolut Pears_
- *`...` same as __Product__*
- `image` Splash fade image (with and without light shining it looks like)
- `image` Weekly drink signup background

#### __Drink recipe__ `absolutdrinks.com/en/drinks/*`
_Example: Mojito, Absolut Mistletoe, Bloody Mary_
- `text` Title/name
- `image` Splash image
- `list<ingredient>` Ingredient list, where each ingredient has:
  - `text` Name
  - `int` Amount
  - `enum` Count system (parts, whole, unspecified)
- `text?` Optional description
- `list<drink>` List of links to other non-alcoholic alternative drinks. _Could be auto generated but who knows._
- `video` How to mix video
- `list<drink>` List of links to similar drinks. _Could be auto generated._

#### __Drinks *party theme*__ `absolutdrinks.com/en/browse/*`
_Example: Bachelorette party, 50's party, Salsa party_
- `text` Title/name
- `text` Summary header
- `text` Summary text
- `text` Do's and Dont's examples
- `list<drink>` List of links to suitable drinks.

#### __Drinks *descriptive group*__ `absolutdrinks.com/en/*`
_Example: Valentine's day cocktails, Martini variations_
- `text` Title/name
- `rich text` Description
- `image` Splash image
- `list<drink>` Drink recommendations

#### __Drinks *learning guide*__ `absolutdrinks.com/en/learn/*`
_Example: Anatomy of a cocktail, Mixing and serving_
- `text` Title/name
- `text` Summary _(viewed with blurred background)_
- `image` Title blurred background
- `content area` Optional content, such as some videos or more text
- `text` Drink recommendations title
- `list<drink>` Drink recommendations

#### __News article__ `absolut.com/en/news/articles/*`
_Example: Midsommar, Out of the blue, Our story_
- `text` Title/name
- `text` Summary
- `image` Optional title splash image _(used in absolut is open & out of the blue)_
- `content area` The article. _No unified structure detected here. Just a bunch of blocks. Sometimes images, sometimes videos, sometimes drinks lists._

#### __Artist page__ `absolut.com/en/artists/*`
_Example: Avantika, Emily Gray_
- `text` Title/name
- `text` Description
- `image` Splash image
- `image` Image of artist
- `link` Link to art store

> *~there are probably a lot more, and many small types, but I stopped here at the 8 most easily noticeable page types.~*

### 3. Block types

_First some of the simpler ones._

- __Text block__
  - `text` Header
  - `rich text` The text block
- __Wide image__
  - `image` The image
  - `content area` Place to put inner content.
- __Video__
  - `video` Some video link, usually youtube
- __Carousel__
  - `text` Header
  - `list<content area>` The carousel items
- __Image grid__
  - `list<image>` All the images.

_Onto the more absolut-specific blocks._

#### __Drink recipe__  
*Sometimes used in articles. Seems disconnected from the drink page type as it usually gives out different recipe than the matching drink page does.*
- `text` Title/name
- `image` Splash image
- `list<text>` List of ingredients.
- `text` Recipe

#### __Drinks category__
*Example: So Hot Right Now, Classic drinks*
- `text` Title/name
- `list<drink link>` Links to drinks
  - `drink` Drink, where I presume the block gets the name from
  - `image` Link image. Seems to be custom ones. Not the same as the drink uses. Maybe a meta attribute on the drink itself?

#### __Party themes list__
*Might as well be same base type as __Drinks category__ or something. But it got different interactions such as hover effects.*
- `text` Title/name
- `list<theme link>` Links to themes
  - `party theme page` Party theme, where I presume the blocks gets the name from.
  - `image` Link image.

#### __Product filtered list__
*Where it filters from viewing all products/swedish products. On the home page.*
- `list<product link>` Swedish products, where the element has:
  - `product` Product in question. To get name and link?
  - `image` Image of the product
- `list<product link>` All products

### 4. Interactive feature

- Signup for weekly drinks
- Filter products on home page
- Search for drinks
- Post questions in the contacts forum
